@@ -3,15 +3,15 @@ from sklearn.preprocessing import PolynomialFeatures
 from scipy.linalg import svd
 
 
-
-
 class MVPR_forward():
 
-    def __init__(self,training_data, training_targets, validation_training,validation_targets):
+    def __init__(self,training_data, training_targets, validation_data,validation_targets, verbose=False, search='exponent'):
         self.training_data= training_data
         self.training_targets = training_targets
-        self.validation_training = validation_training
+        self.validation_data = validation_data
         self.validation_targets = validation_targets
+        self.verbose = verbose
+        self.search = search
 
     def TSVD_error(self,X_val,V,S,U,ind):
 
@@ -38,17 +38,22 @@ class MVPR_forward():
         F_ind_low_1, CM = self.TSVD_error(X_val, V, S, U, ind_low_1)
         F_ind_high_1, CM = self.TSVD_error(X_val, V, S, U, ind_high_1)
 
-        # F_ind_lower = [F_ind_low_1]
-        # F_ind_higher = [F_ind_high_1]
-        # ind_lower = [ind_low_1]
-        # ind_higher = [ind_high_1]
         LL = 1
 
         while LL < 20:
 
-            distance = 0.61803398875 * (np.log10(ind_high_1) - np.log10(ind_low_1))
-            ind_low_2 = round(10 ** (np.log10(ind_high_1) - distance))
-            ind_high_2 = round(10 ** (np.log10(ind_low_1) + distance))
+            if self.verbose:
+                print('       Truncation point Low = ', ind_low_1, ', Cross validation MPEN = ', F_ind_low_1,
+                      ' || Truncation point High = ', ind_high_1, ', Cross validation MPEN = ', F_ind_high_1)
+
+            if self.search == 'exponent':
+                distance = 0.61803398875 * (np.log10(ind_high_1) - np.log10(ind_low_1))
+                ind_low_2 = round(10 ** (np.log10(ind_high_1) - distance))
+                ind_high_2 = round(10 ** (np.log10(ind_low_1) + distance))
+            else:
+                distance = 0.61803398875 * (ind_high_1 - ind_low_1)
+                ind_low_2 = round(ind_high_1 - distance)
+                ind_high_2 = round(ind_low_1 + distance)
 
 
             F_ind_low_2, CM = self.TSVD_error(X_val, V, S, U, ind_low_2)
@@ -57,25 +62,26 @@ class MVPR_forward():
 
             if F_ind_low_2 > F_ind_high_2:
                 ind_low_1 = ind_low_2
-                # [F_ind_low_1] = F_ind_low_2
-                # F_ind_lower = [F_ind_lower F_ind_low_1]
-                # ind_lower = [ind_lower ind_low_1]
+                F_ind_low_1 = F_ind_low_2
+
 
 
             if F_ind_low_2 < F_ind_high_2:
                 ind_high_1 = ind_high_2
-                # [F_ind_high_1] = F_ind_high_2
-                # F_ind_higher = [F_ind_higher F_ind_high_1]
-                # ind_higher = [ind_higher ind_high_1]
-
-
+                F_ind_high_1 = F_ind_high_2
 
             LL = LL + 1
 
+        if self.verbose:
+            print('       Truncation point Low = ', ind_low_1, ', Cross validation MPEN = ', F_ind_low_1,
+                  ' || Truncation point High = ', ind_high_1, ', Cross validation MPEN = ', F_ind_high_1)
 
+        if self.search == 'exponent':
+            ind_exp = (np.log10(ind_high_1) + np.log10(ind_low_1))/2
+            ind = round(10**ind_exp)
+        else:
+            ind = round((ind_low_1 + ind_high_1) / 2)
 
-
-        ind = ((ind_low_1 + ind_high_1) / 2)
         error, CM = self.TSVD_error(X_val, V, S, U, int(ind))
 
         return error, CM
@@ -88,9 +94,10 @@ class MVPR_forward():
         for i in range(0,len(order),1):
             poly = PolynomialFeatures(degree=order[i])
             X_train=poly.fit_transform(self.training_data)
-            X_val = poly.fit_transform(self.validation_training)
+            X_val = poly.fit_transform(self.validation_data)
             error[i], dummy=self.GSS(X_train,X_val)
-            #print('order = ', order[i], '| error = ', error[i])
+            if self.verbose:
+                print('order = ', order[i], '| error = ', error[i])
         optimum_order_index = np.where(np.min(error) == error)
         optimum_order = int(order[optimum_order_index])
         return optimum_order
@@ -98,7 +105,7 @@ class MVPR_forward():
     def compute_CM(self, order):
         poly = PolynomialFeatures(degree=order)
         X_train = poly.fit_transform(self.training_data)
-        X_val = poly.fit_transform(self.validation_training)
+        X_val = poly.fit_transform(self.validation_data)
         error, CM =  self.GSS(X_train, X_val)
 
         return CM
